# methylGrapher


## methylGrapher: Genome-Graph-Based DNA Methylation Analysis Using Whole Genome Bisulfite Sequencing

## Quick start guide
For downloading and installing the package, please follow the instructions below:
[Installation](https://twlab.github.io/methylGrapher/build/html/install.html)<br>
The toy example to show successful installation is available at:
[Example](https://twlab.github.io/methylGrapher/build/html/example.html)<br>
The usage of the package is available at:
[Usage](https://twlab.github.io/methylGrapher/build/html/process.html)

## Issues
If you encounter any issues, please report them at: [Tracker](https://github.com/twlab/methylGrapher/issues)

## Full Documentation
[ReadTheDocs](https://twlab.github.io/methylGrapher/build/html/)


## Scripts used for the paper
[Analysis](https://github.com/Hendricks27/methylGrapher_paper)


